package application

import (
	"encoding/json"
	"fmt"
	"net/http"
	"sirlab.de/go/knowyt/game"
	"sirlab.de/go/knowyt/user"
)

type Games struct {
	Games map[string]*game.GameInfoJson `json:"games"`
}

func (app *Application) GetGames(usr *user.User, w http.ResponseWriter, r *http.Request) {
	if !usr.IsAdmin() {
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	app.mu.Lock()
	defer app.mu.Unlock()

	games := Games{
		Games: make(map[string]*game.GameInfoJson),
	}
	for k, gm := range app.games {
		games.Games[k] = gm.GetGameInfo()
	}

	w.Header().Add("Content-Type", "application/json")
	jsonString, _ := json.Marshal(games)
	fmt.Fprintf(w, string(jsonString))
}
